package net.minecraft.src.railcraft.common.api;

public enum EnumSignalAspect
{

    GREEN(0),
    BLINK_YELLOW(1),
    YELLOW(1),
    BLINK_RED(2),
    RED(2),
    OFF(3);
    private final byte id;
    private final int textureOffset;
    private static byte nextId = 0;
    private static boolean blinkState;

    private EnumSignalAspect(int textureOffset)
    {
        this.textureOffset = textureOffset;
        id = getNextId();
    }

    public byte getId()
    {
        return id;
    }

    public int getTextureOffset()
    {
        return textureOffset;
    }

    public boolean isBlinkAspect()
    {
        if(this == BLINK_YELLOW || this == BLINK_RED)
        {
            return true;
        }
        return false;
    }

    public static boolean getBlinkState()
    {
        return blinkState;
    }

    public static void invertBlinkState()
    {
        blinkState = !blinkState;
    }

    public static EnumSignalAspect fromId(int id)
    {
        for(EnumSignalAspect a : EnumSignalAspect.values())
        {
            if(a.getId() == id)
            {
                return a;
            }
        }
        return RED;
    }

    public static EnumSignalAspect mostRestrictive(EnumSignalAspect first, EnumSignalAspect second)
    {
        if(first == null && second != null)
        {
            return second;
        } else if(first != null && second == null)
        {
            return first;
        } else if(first == null && second == null)
        {
            return RED;
        }
        if(first == OFF || second == OFF)
        {
            return RED;
        }
        if(first.getId() > second.getId())
        {
            return first;
        }
        return second;
    }

    private static byte getNextId()
    {
        byte i = nextId;
        nextId++;
        return i;
    }

    @Override
    public String toString()
    {
        String[] sa = name().split("_");
        String out = "";
        for(String s : sa)
        {
            out = out + s.substring(0, 1) + s.substring(1).toLowerCase() + " ";
        }
        out = out.trim();
        return out;
    }
}
